@@ -1,5 +1,5 @@
 package Selenium::Remote::WebElement;
-$Selenium::Remote::WebElement::VERSION = '1.24';
+
 # ABSTRACT: Representation of an HTML Element used by Selenium Remote Driver
 
 use strict;
@@ -8,305 +8,6 @@ use warnings;
 use Moo;
 use Carp qw(carp croak);
 
-
-has 'id' => (
-    is => 'ro',
-    required => 1,
-    coerce => sub {
-        my ($value) = @_;
-        if (ref($value) eq 'HASH') {
-            if (exists $value->{ELEMENT}) {
-                # The JSONWireProtocol web element object looks like
-                #
-                #     { "ELEMENT": $INTEGER_ID }
-                return $value->{ELEMENT};
-            }
-            elsif (exists $value->{'element-6066-11e4-a52e-4f735466cecf'}) {
-                # but the WebDriver spec web element uses a magic
-                # string. See the spec for more information:
-                #
-                # https://www.w3.org/TR/webdriver/#elements
-                return $value->{'element-6066-11e4-a52e-4f735466cecf'};
-            }
-            else {
-                croak 'When passing in an object to the WebElement id attribute, it must have at least one of the ELEMENT or element-6066-11e4-a52e-4f735466cecf keys.';
-            }
-        }
-        else {
-            return $value;
-        }
-    }
-);
-
-has 'driver' => (
-    is => 'ro',
-    required => 1,
-    handles => [qw(_execute_command)],
-);
-
-
-sub click {
-    my ($self) = @_;
-    my $res = { 'command' => 'clickElement', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub submit {
-    my ($self) = @_;
-    return $self->driver->execute_script("if (typeof arguments[0].submit === 'function') { return arguments[0].submit(); }; return 0;", {'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}} ) if $self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge});
-    my $res = { 'command' => 'submitElement', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub send_keys {
-    my ( $self, @strings ) = @_;
-    croak "no keys to send" unless scalar @strings >= 1;
-    my $res = { 'command' => 'sendKeysToElement', 'id' => $self->id };
-
-    # We need to send an array of single characters to be WebDriver
-    # spec compatible. That is, for @strings = ('hel', 'lo'), the
-    # corresponding value must be ('h', 'e', 'l', 'l', 'o' ). This
-    # format conforms with the Spec AND works with the Selenium
-    # standalone server.
-    my $strings = join('', map { $_."" } @strings);
-    my $params = {
-        'value' => [ split('', $strings) ],
-        text => $strings,
-    };
-    return $self->_execute_command( $res, $params );
-}
-
-
-sub is_selected {
-    my ($self) = @_;
-
-    return $self->get_property('checked') if $self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge});
-    my $res = { 'command' => 'isElementSelected', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub set_selected {
-    my ($self) = @_;
-    if ($self->driver->{is_wd3}) {
-        return if $self->is_selected();
-        return $self->click();
-    }
-    my $res = { 'command' => 'setElementSelected', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub toggle {
-    my ($self) = @_;
-    if ($self->driver->{is_wd3}) {
-        return $self->click() unless $self->is_selected();
-        return $self->driver->execute_script(qq/ if (arguments[0].checked) { arguments[0].checked = 0 }; return arguments[0].checked; /, {'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}});
-    }
-    my $res = { 'command' => 'toggleElement', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub is_enabled {
-    my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
-        return 1 if $self->get_tag_name() ne 'input';
-        return $self->get_property('disabled') ? 0 : 1;
-    }
-    my $res = { 'command' => 'isElementEnabled', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub get_element_location {
-    my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
-        my $data = $self->get_element_rect();
-        delete $data->{height};
-        delete $data->{width};
-        return $data;
-    }
-    my $res = { 'command' => 'getElementLocation', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub get_size {
-    my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
-        my $data = $self->get_element_rect();
-        delete $data->{x};
-        delete $data->{y};
-        return $data;
-    }
-    my $res = { 'command' => 'getElementSize', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-
-sub get_element_rect {
-    my ($self) = @_;
-    my $res = { 'command' => 'getElementRect', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub get_element_location_in_view {
-    my ($self) = @_;
-    #XXX chrome is dopey here
-    return $self->driver->execute_script(qq{
-        if (typeof(arguments[0]) !== 'undefined' && arguments[0].nodeType === Node.ELEMENT_NODE) {
-            arguments[0].scrollIntoView();
-            var pos = arguments[0].getBoundingClientRect();
-            return {y:pos.top,x:pos.left};
-        }
-        return {};
-    }, {'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}} ) if $self->driver->{is_wd3} && grep { $self->driver->browser_name eq $_ } ('firefox','internet explorer');
-    my $res = { 'command' => 'getElementLocationInView', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub get_tag_name {
-    my ($self) = @_;
-    my $res = { 'command' => 'getElementTagName', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub clear {
-    my ($self) = @_;
-    my $res = { 'command' => 'clearElement', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub get_attribute {
-    my ( $self, $attr_name, $no_i_really_mean_it ) = @_;
-    if ( not defined $attr_name ) {
-        croak 'Attribute name not provided';
-    }
-    return $self->get_property($attr_name) if $self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge}) && !$no_i_really_mean_it;
-
-    my $res = {
-        'command' => 'getElementAttribute',
-        'id'      => $self->id,
-        'name'    => $attr_name,
-    };
-    return $self->_execute_command($res);
-}
-
-
-sub get_property {
-    my ($self,$prop) = @_;
-    return $self->get_attribute($prop) if $self->driver->{is_wd3} && (grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge});
-    my $res = { 'command' => 'getElementProperty', id => $self->id, name => $prop };
-    return $self->_execute_command($res);
-}
-
-
-
-sub get_value {
-    my ($self) = @_;
-    return $self->get_attribute('value');
-}
-
-
-sub is_displayed {
-    my ($self) = @_;
-    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
-        return 0 if $self->get_tag_name() eq 'input' && $self->get_property('type') eq 'hidden'; #hidden type inputs
-        return int($self->get_css_attribute('display') ne 'none');
-    }
-    my $res = { 'command' => 'isElementDisplayed', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub is_hidden {
-    my ($self) = @_;
-    return ! $self->is_displayed();
-}
-
-
-sub drag {
-    my ($self,$target) = @_;
-    require Selenium::ActionChains;
-    my $chain = Selenium::ActionChians->new( driver => $self->driver );
-    return $chain->drag_and_drop($self,$target)->perform();
-}
-
-
-sub get_text {
-    my ($self) = @_;
-    my $res = { 'command' => 'getElementText', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub get_css_attribute {
-    my ( $self, $attr_name ) = @_;
-    if ( not defined $attr_name ) {
-        croak 'CSS attribute name not provided';
-    }
-    my $res = {
-        'command'       => 'getElementValueOfCssProperty',
-        'id'            => $self->id,
-        'property_name' => $attr_name,
-    };
-    return $self->_execute_command($res);
-}
-
-
-sub describe {
-    my ($self) = @_;
-    my $res = { 'command' => 'describeElement', 'id' => $self->id };
-    return $self->_execute_command($res);
-}
-
-
-sub screenshot {
-    my ($self, $scroll) = @_;
-    $scroll //= 1;
-    my $res = { 'command' => 'elementScreenshot', id => $self->id };
-    my $input = {scroll => int($scroll) };
-    return $self->_execute_command($res, $input);
-}
-
-
-sub capture_screenshot {
-    my ( $self, $filename, $scroll ) = @_;
-    croak '$filename is required' unless $filename;
-
-    open( my $fh, '>', $filename );
-    binmode $fh;
-    print $fh MIME::Base64::decode_base64( $self->screenshot($scroll) );
-    CORE::close $fh;
-    return 1;
-}
-
-
-
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Selenium::Remote::WebElement - Representation of an HTML Element used by Selenium Remote Driver
-
-=head1 VERSION
-
-version 1.24
-
 =head1 DESCRIPTION
 
 Selenium Webdriver represents all the HTML elements as WebElements.
@@ -371,6 +72,43 @@ at all. For further reading, the L<W3C
 spec|https://www.w3.org/TR/webdriver/#elements> strictly dictates the
 exact behavior.
 
+=cut
+
+has 'id' => (
+    is => 'ro',
+    required => 1,
+    coerce => sub {
+        my ($value) = @_;
+        if (ref($value) eq 'HASH') {
+            if (exists $value->{ELEMENT}) {
+                # The JSONWireProtocol web element object looks like
+                #
+                #     { "ELEMENT": $INTEGER_ID }
+                return $value->{ELEMENT};
+            }
+            elsif (exists $value->{'element-6066-11e4-a52e-4f735466cecf'}) {
+                # but the WebDriver spec web element uses a magic
+                # string. See the spec for more information:
+                #
+                # https://www.w3.org/TR/webdriver/#elements
+                return $value->{'element-6066-11e4-a52e-4f735466cecf'};
+            }
+            else {
+                croak 'When passing in an object to the WebElement id attribute, it must have at least one of the ELEMENT or element-6066-11e4-a52e-4f735466cecf keys.';
+            }
+        }
+        else {
+            return $value;
+        }
+    }
+);
+
+has 'driver' => (
+    is => 'ro',
+    required => 1,
+    handles => [qw(_execute_command)],
+);
+
 =head1 FUNCTIONS
 
 =head2 click
@@ -381,6 +119,14 @@ exact behavior.
  Usage:
     $elem->click();
 
+=cut
+
+sub click {
+    my ($self) = @_;
+    my $res = { 'command' => 'clickElement', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 submit
 
  Description:
@@ -388,12 +134,21 @@ exact behavior.
     that is a descendant of a FORM element.
 
  Compatibility:
-    On webdriver3 enabled servers, this uses a JS shim, which may not submit correctly depending on the element you are attempting to submit.
+    On webdriver3 enabled servers, this uses a JS shim, which WILL NOT submit correctly unless your element is an <input>.
     Try clicking it if possible instead.
 
  Usage:
     $elem->submit();
 
+=cut
+
+sub submit {
+    my ($self) = @_;
+    return $self->driver->execute_script("return arguments[0].form.submit();",{'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}} ) if $self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge});
+    my $res = { 'command' => 'submitElement', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 send_keys
 
  Description:
@@ -417,6 +172,26 @@ exact behavior.
     .
     $elem->send_keys(KEYS->{'space'}, KEYS->{'enter'});
 
+=cut
+
+sub send_keys {
+    my ( $self, @strings ) = @_;
+    croak "no keys to send" unless scalar @strings >= 1;
+    my $res = { 'command' => 'sendKeysToElement', 'id' => $self->id };
+
+    # We need to send an array of single characters to be WebDriver
+    # spec compatible. That is, for @strings = ('hel', 'lo'), the
+    # corresponding value must be ('h', 'e', 'l', 'l', 'o' ). This
+    # format conforms with the Spec AND works with the Selenium
+    # standalone server.
+    my $strings = join('', map { $_."" } @strings);
+    my $params = {
+        'value' => [ split('', $strings) ],
+        text => $strings,
+    };
+    return $self->_execute_command( $res, $params );
+}
+
 =head2 is_selected
 
  Description:
@@ -429,6 +204,16 @@ exact behavior.
  Usage:
     $elem->is_selected();
 
+=cut
+
+sub is_selected {
+    my ($self) = @_;
+
+    return $self->get_property('checked') if $self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge});
+    my $res = { 'command' => 'isElementSelected', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 set_selected
 
  Description:
@@ -438,6 +223,18 @@ exact behavior.
  Usage:
     $elem->set_selected();
 
+=cut
+
+sub set_selected {
+    my ($self) = @_;
+    if ($self->driver->{is_wd3}) {
+        return if $self->is_selected();
+        return $self->click();
+    }
+    my $res = { 'command' => 'setElementSelected', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 toggle
 
  Description:
@@ -450,6 +247,18 @@ exact behavior.
  Usage:
     $elem->toggle();
 
+=cut
+
+sub toggle {
+    my ($self) = @_;
+    if ($self->driver->{is_wd3}) {
+        return $self->click() unless $self->is_selected();
+        return $self->driver->execute_script(qq/ if (arguments[0].checked) { arguments[0].checked = 0 }; return arguments[0].checked; /, {'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}});
+    }
+    my $res = { 'command' => 'toggleElement', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 is_enabled
 
  Description:
@@ -461,6 +270,18 @@ exact behavior.
  Usage:
     $elem->is_enabled();
 
+=cut
+
+sub is_enabled {
+    my ($self) = @_;
+    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
+        return 1 if $self->get_tag_name() ne 'input';
+        return $self->get_property('disabled') ? 0 : 1;
+    }
+    my $res = { 'command' => 'isElementEnabled', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 get_element_location
 
  Description:
@@ -478,6 +299,20 @@ exact behavior.
 
  This method is DEPRECATED on webdriver3 enabled servers.
 
+=cut
+
+sub get_element_location {
+    my ($self) = @_;
+    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
+        my $data = $self->get_element_rect();
+        delete $data->{height};
+        delete $data->{width};
+        return $data;
+    }
+    my $res = { 'command' => 'getElementLocation', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 get_size
 
  Description:
@@ -495,6 +330,21 @@ exact behavior.
 
  This method is DEPRECATED on webdriver3 enabled servers.
 
+=cut
+
+sub get_size {
+    my ($self) = @_;
+    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
+        my $data = $self->get_element_rect();
+        delete $data->{x};
+        delete $data->{y};
+        return $data;
+    }
+    my $res = { 'command' => 'getElementSize', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
+
 =head2 get_element_rect
 
 Get the element's size AND location in a hash.
@@ -503,6 +353,14 @@ Example Output:
 
     { x => 0, y => 0, height => 10, width => 10 }
 
+=cut
+
+sub get_element_rect {
+    my ($self) = @_;
+    my $res = { 'command' => 'getElementRect', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 get_element_location_in_view
 
  Description:
@@ -523,6 +381,23 @@ Example Output:
  Usage:
     $elem->get_element_location_in_view();
 
+=cut
+
+sub get_element_location_in_view {
+    my ($self) = @_;
+    #XXX chrome is dopey here
+    return $self->driver->execute_script(qq{
+        if (typeof(arguments[0]) !== 'undefined' && arguments[0].nodeType === Node.ELEMENT_NODE) {
+            arguments[0].scrollIntoView();
+            var pos = arguments[0].getBoundingClientRect();
+            return {y:pos.top,x:pos.left};
+        }
+        return {};
+    }, {'element-6066-11e4-a52e-4f735466cecf'=> $self->{id}} ) if $self->driver->{is_wd3} && grep { $self->driver->browser_name eq $_ } ('firefox','internet explorer');
+    my $res = { 'command' => 'getElementLocationInView', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 get_tag_name
 
  Description:
@@ -534,6 +409,14 @@ Example Output:
  Usage:
     $elem->get_tag_name();
 
+=cut
+
+sub get_tag_name {
+    my ($self) = @_;
+    my $res = { 'command' => 'getElementTagName', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 clear
 
  Description:
@@ -542,6 +425,14 @@ Example Output:
  Usage:
     $elem->clear();
 
+=cut
+
+sub clear {
+    my ($self) = @_;
+    my $res = { 'command' => 'clearElement', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 get_attribute
 
  Description:
@@ -565,6 +456,23 @@ Example Output:
  Usage:
     $elem->get_attribute('name',1);
 
+=cut
+
+sub get_attribute {
+    my ( $self, $attr_name, $no_i_really_mean_it ) = @_;
+    if ( not defined $attr_name ) {
+        croak 'Attribute name not provided';
+    }
+    return $self->get_property($attr_name) if $self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge}) && !$no_i_really_mean_it;
+
+    my $res = {
+        'command' => 'getElementAttribute',
+        'id'      => $self->id,
+        'name'    => $attr_name,
+    };
+    return $self->_execute_command($res);
+}
+
 =head2 get_property
 
 Gets the C<Current Value> of an element's attribute.
@@ -573,6 +481,16 @@ Takes a named property as an argument.
 
 Only available on WebDriver 3 enabled servers.
 
+=cut
+
+sub get_property {
+    my ($self,$prop) = @_;
+    return $self->get_attribute($prop) if $self->driver->{is_wd3} && (grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge});
+    my $res = { 'command' => 'getElementProperty', id => $self->id, name => $prop };
+    return $self->_execute_command($res);
+}
+
+
 =head2 get_value
 
  Description:
@@ -584,6 +502,13 @@ Only available on WebDriver 3 enabled servers.
  Usage:
     $elem->get_value();
 
+=cut
+
+sub get_value {
+    my ($self) = @_;
+    return $self->get_attribute('value');
+}
+
 =head2 get_style
 
 =head2 is_displayed
@@ -598,6 +523,18 @@ Only available on WebDriver 3 enabled servers.
  Usage:
     $elem->is_displayed();
 
+=cut
+
+sub is_displayed {
+    my ($self) = @_;
+    if ($self->driver->{is_wd3} && !(grep { $self->driver->browser_name eq $_ } qw{chrome MicrosoftEdge})) {
+        return 0 if $self->get_tag_name() eq 'input' && $self->get_property('type') eq 'hidden'; #hidden type inputs
+        return int($self->get_css_attribute('display') ne 'none');
+    }
+    my $res = { 'command' => 'isElementDisplayed', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 is_hidden
 
  Description:
@@ -609,6 +546,13 @@ Only available on WebDriver 3 enabled servers.
  Usage:
     $elem->is_hidden();
 
+=cut
+
+sub is_hidden {
+    my ($self) = @_;
+    return ! $self->is_displayed();
+}
+
 =head2 drag
 
 Alias for Selenium::ActionChains::drag_and_drop().
@@ -619,6 +563,15 @@ Provide element you wish to drag to as argument.
     my $subject = $driver->find_element('thingy','id');
     $subject->drag($target);
 
+=cut
+
+sub drag {
+    my ($self,$target) = @_;
+    require Selenium::ActionChains;
+    my $chain = Selenium::ActionChians->new( driver => $self->driver );
+    return $chain->drag_and_drop($self,$target)->perform();
+}
+
 =head2 get_text
 
  Description:
@@ -630,6 +583,14 @@ Provide element you wish to drag to as argument.
  Usage:
     $elem->get_text();
 
+=cut
+
+sub get_text {
+    my ($self) = @_;
+    my $res = { 'command' => 'getElementText', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 get_css_attribute
 
  Description:
@@ -647,6 +608,21 @@ Provide element you wish to drag to as argument.
  Usage:
     $elem->get_css_attribute('background-color');
 
+=cut
+
+sub get_css_attribute {
+    my ( $self, $attr_name ) = @_;
+    if ( not defined $attr_name ) {
+        croak 'CSS attribute name not provided';
+    }
+    my $res = {
+        'command'       => 'getElementValueOfCssProperty',
+        'id'            => $self->id,
+        'property_name' => $attr_name,
+    };
+    return $self->_execute_command($res);
+}
+
 =head2 describe
 
  Description:
@@ -660,6 +636,14 @@ Provide element you wish to drag to as argument.
 
  Entirely unsupported on WebDriver 3 enabled servers.
 
+=cut
+
+sub describe {
+    my ($self) = @_;
+    my $res = { 'command' => 'describeElement', 'id' => $self->id };
+    return $self->_execute_command($res);
+}
+
 =head2 screenshot
 
  Description:
@@ -680,6 +664,16 @@ Provide element you wish to drag to as argument.
 
 To conveniently write the screenshot to a file, see L</capture_screenshot>.
 
+=cut
+
+sub screenshot {
+    my ($self, $scroll) = @_;
+    $scroll //= 1;
+    my $res = { 'command' => 'elementScreenshot', id => $self->id };
+    my $input = {scroll => int($scroll) };
+    return $self->_execute_command($res, $input);
+}
+
 =head2 capture_screenshot
 
  Description:
@@ -698,83 +692,19 @@ To conveniently write the screenshot to a file, see L</capture_screenshot>.
  Usage:
     $element->capture_screenshot($filename);
 
-=head1 SEE ALSO
-
-Please see those modules/websites for more information related to this module.
-
-=over 4
-
-=item *
-
-L<Selenium::Remote::Driver|Selenium::Remote::Driver>
-
-=back
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=head1 AUTHORS
-
-Current Maintainers:
-
-=over 4
-
-=item *
-
-Daniel Gempesaw <gempesaw@gmail.com>
-
-=item *
-
-Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
-
-=back
-
-Previous maintainers:
-
-=over 4
-
-=item *
-
-Luke Closs <cpan@5thplane.com>
-
-=item *
-
-Mark Stosberg <mark@stosberg.com>
-
-=back
-
-Original authors:
-
-=over 4
-
-=item *
-
-Aditya Ivaturi <ivaturi@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
-
-Copyright (c) 2014-2017 Daniel Gempesaw
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-
 =cut
+
+sub capture_screenshot {
+    my ( $self, $filename, $scroll ) = @_;
+    croak '$filename is required' unless $filename;
+
+    open( my $fh, '>', $filename );
+    binmode $fh;
+    print $fh MIME::Base64::decode_base64( $self->screenshot($scroll) );
+    CORE::close $fh;
+    return 1;
+}
+
+
+
+1;
